==> magify-sdk-4.6.2.zip: CHANGELOG.md <==
# 🧙 Magify Unity3d SDK

[![sdk](https://img.shields.io/badge/sdk-4.6.2-green)](https://github.com/Magify-LTD/magify-unity)
[![service](https://img.shields.io/badge/service-4.6.2-green)](https://github.com/Magify-LTD/magify-unity)

```
{
  "dependencies": {
    "com.magify.unity-sdk": "file:com.magify.unity-sdk-4.6.2.tgz",
    "com.magify.unity-sdk-service": "file:com.magify.unity-sdk-service-4.6.2.tgz",
    ...
  },
}
```

> **Full documentation with example at [version page](https://magify.atlassian.net/wiki/spaces/GW/pages/1280164/Releases).**


# Change Log

## [4.6.2]
### Release 4.6.0
- [SDK] Full support of Unity 6 (#747)
### Release 4.6.1
- [SDK/Service] Support of Aghanim web store (#744)
- [Service] Added UPM as a source of `External dependency manager` dependency (#744)
- [SDK] Made improvement to be more likely to be able to send a request to save progress when app is going to the background (#748)
- [Service/SDK] Renamed sync-state and social-auth related API (#752)
### Release 4.6.2
- [SDK] Cleared some parameters for in-app tracking and added xml documentation (#753)
- [SDK] Added public method `MagifyManager.IsApplicationInstalled()` (#753)

# CONTACTS

| #  | Name                                                                                                            | Position             |
|:--:|-----------------------------------------------------------------------------------------------------------------|----------------------|
| 1  | [Kirill Dudnik](https://magifycom.slack.com/team/U074KHLMRAA) ([email](kirill.dudnik@magify.com))               | Unity                |
| 2  | [Vitaliy Borisovec](https://magifycom.slack.com/team/U08FCCTAP4Y) ([email](vitaliy.borisovec@magify.com))       | Unity                |

==> magify-sdk-4.6.4.zip: CHANGELOG.md <==
# 🧙 Magify Unity3d SDK

[![sdk](https://img.shields.io/badge/sdk-4.6.4-green)](https://github.com/Magify-LTD/magify-unity)
[![service](https://img.shields.io/badge/service-4.6.4-green)](https://github.com/Magify-LTD/magify-unity)

```
{
  "dependencies": {
    "com.magify.unity-sdk": "file:com.magify.unity-sdk-4.6.4.tgz",
    "com.magify.unity-sdk-service": "file:com.magify.unity-sdk-service-4.6.4.tgz",
    ...
  },
}
```

> **Full documentation with example at [version page](https://magify.atlassian.net/wiki/spaces/GW/pages/1280164/Releases).**


# Change Log

## [4.6.4]
### Release 4.6.0
- [SDK] Full support of Unity 6 (#747)
### Release 4.6.1
- [SDK/Service] Support of Aghanim web store (#744)
- [Service] Added UPM as a source of `External dependency manager` dependency (#744)
- [SDK] Made improvement to be more likely to be able to send a request to save progress when app is going to the background (#748)
- [Service/SDK] Renamed sync-state and social-auth related API (#752)
### Release 4.6.2
- [SDK] Cleared some parameters for in-app tracking and added xml documentation (#753)
- [SDK] Added public method `MagifyManager.IsApplicationInstalled()` (#753)
### Release 4.6.3
- [SDK] Added opportunity to get `MagifyManager.CommonClientId` (#755)
### Release 4.6.4
- [SDK] Exceptions when fetching GAID are converted to LogWarning (#756)

# CONTACTS

| #  | Name                                                                                                            | Position             |
|:--:|-----------------------------------------------------------------------------------------------------------------|----------------------|
| 1  | [Kirill Dudnik](https://magifycom.slack.com/team/U074KHLMRAA) ([email](kirill.dudnik@magify.com))               | Unity                |
| 2  | [Vitaliy Borisovec](https://magifycom.slack.com/team/U08FCCTAP4Y) ([email](vitaliy.borisovec@magify.com))       | Unity                |
